##
##  pinentry.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         pinentry
Summary:      Interactive PIN Entry Dialogs
URL:          http://www.gnupg.org/related_software/pinentry/
Vendor:       R. Bihlmeyer, W. Koch, S. Hansen, M. Brinkmann
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Terminal
License:      GPL
Version:      1.3.0
Release:      20240319

#   list of sources
Source0:      ftp://ftp.gnupg.org/gcrypt/pinentry/pinentry-%{version}.tar.bz2

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  ncurses, libiconv, libassuan
PreReq:       ncurses, libiconv, libassuan

%description
    PINentry is a collection of simple PIN or passphrase entry dialogs
    which utilize the Assuan protocol as described by the GnuPG
    and Aegypten projects. It allows applications like GnuPG to
    interactively request PINs or passphrases.

%track
    prog pinentry = {
        version   = %{version}
        url       = ftp://ftp.gnupg.org/gcrypt/pinentry/
        regex     = pinentry-(__VER__)\.tar\.bz2
    }

%prep
    %setup -q

%build
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    CPPFLAGS="%{l_cppflags ncurses .}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --infodir=%{l_prefix}/info \
        --enable-pinentry-curses \
        --enable-fallback-curses \
        --with-ncurses-include-dir=%{l_prefix}/include/ncurses \
        --disable-pinentry-gtk2 \
        --disable-pinentry-qt
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

